import {
  deleteItem,
  DeleteItemProps,
} from "@supabase-cache-helpers/postgrest-mutate";
import { useSWRConfig } from "swr";

import { decode, usePostgrestFilterCache } from "../lib";

/**
 * Convenience hook to delete an item from the swr cache. Does not make any http requests, and is supposed to be used for custom cache updates.
 * @param opts The mutation options
 * @returns void
 */
export function useDeleteItem<Type extends Record<string, unknown>>(
  opts: Omit<DeleteItemProps<Type>, "input">
) {
  const { mutate, cache } = useSWRConfig();
  const getPostgrestFilter = usePostgrestFilterCache();

  return async (input: Type) =>
    await deleteItem(
      {
        input,
        ...opts,
      },
      {
        cacheKeys: Array.from(cache.keys()),
        getPostgrestFilter,
        mutate,
        decode,
      }
    );
}
